@@ -1,10 +1,12 @@
 package Form::Toolkit::Field;
 {
-  $Form::Toolkit::Field::VERSION = '0.002';
+  $Form::Toolkit::Field::VERSION = '0.003';
 }
 use Moose -traits => 'Form::Toolkit::Meta::Class::Trait::HasShortClass';
 use Moose::Util qw/apply_all_roles/;
 
+use Class::Load;
+
 with qw(MooseX::Clone);
 
 __PACKAGE__->meta->short_class('GenericField');
@@ -194,7 +196,7 @@ sub add_role{
 
   ## This is better, as apply can be used to add new arguments
   ## See http://search.cpan.org/~ether/Moose-2.0801/lib/Moose/Role.pm#APPLYING_ROLES
-  Class::MOP::load_class( $role );
+  Class::Load::load_class( $role );
   $role->meta->apply($self, rebless_params => $new_args );
 
   ## Maintain important meta attributes.
